==> adfurikun-1.2.0.tar.gz: ios/Classes/OptionsManager.swift <==
import Foundation
import Flutter
import ADFMovieReward

class OptionsManager {
    static func handle(_ call: FlutterMethodCall, _ result: @escaping FlutterResult) {
        switch call.method {
        case ADFConst.METHOD_SET_USER_GENDER_OTHER:
            ADFMovieOptions.setUserGender(.other)
            break
        case ADFConst.METHOD_SET_USER_GENDER_MALE:
            ADFMovieOptions.setUserGender(.male)
            break
        case ADFConst.METHOD_SET_USER_GENDER_FEMALE:
            ADFMovieOptions.setUserGender(.female)
            break
        case ADFConst.METHOD_SET_USER_AGE:
            if let args = call.arguments as? [String: Any?],
               let age = args[ADFConst.KEY_INT] as? Int32 {
                ADFMovieOptions.setUserAge(age)
            }
            break
        case ADFConst.METHOD_SET_TEST_MODE:
            if let args = call.arguments as? [String: Any?],
               let mode = args[ADFConst.KEY_BOOL] as? Bool {
                ADFMovieOptions.setTestMode(mode)
            }
            break
        case ADFConst.METHOD_SET_USER_CONSENT:
            if let args = call.arguments as? [String: Any?],
               let hasConsent = args[ADFConst.KEY_BOOL] as? Bool {
                ADFMovieOptions.setHasUserConsent(hasConsent)
            }
            break
        case ADFConst.METHOD_SET_SOUND_STATE:
            if let args = call.arguments as? [String: Any?],
               let state = args[ADFConst.KEY_BOOL] as? Bool {
                if state == true {
                    ADFMovieOptions.setSoundState(.on)
                } else {
                    ADFMovieOptions.setSoundState(.off)
                }
            } else {
                ADFMovieOptions.setSoundState(.default)
            }
            break
        case ADFConst.METHOD_OUTPUT_DETAILED_LOG:
            ADFLogger.logLevel = .verbose
            break
        default:
            print("[ADF WARNING] \(call.method) method is not implemented")
        }
    }
}

==> adfurikun-1.5.0.tar.gz: ios/Classes/OptionsManager.swift <==
import Foundation
import Flutter
import ADFMovieReward

class OptionsManager {
    static func handle(_ call: FlutterMethodCall, _ result: @escaping FlutterResult) {
        switch call.method {
        case ADFConst.METHOD_SET_TEST_MODE:
            if let args = call.arguments as? [String: Any?],
               let mode = args[ADFConst.KEY_BOOL] as? Bool {
                ADFMovieOptions.setTestMode(mode)
            }
            break
        case ADFConst.METHOD_SET_USER_CONSENT:
            if let args = call.arguments as? [String: Any?],
               let hasConsent = args[ADFConst.KEY_BOOL] as? Bool {
                ADFMovieOptions.setHasUserConsent(hasConsent)
            }
            break
        case ADFConst.METHOD_SET_SOUND_STATE:
            if let args = call.arguments as? [String: Any?],
               let state = args[ADFConst.KEY_BOOL] as? Bool {
                if state == true {
                    ADFMovieOptions.setSoundState(.on)
                } else {
                    ADFMovieOptions.setSoundState(.off)
                }
            } else {
                ADFMovieOptions.setSoundState(.default)
            }
            break
        case ADFConst.METHOD_SET_REGION:
            if let args = call.arguments as? [String: Any?],
               let region = args[ADFConst.KEY_STRING] as? String {
                if region == ADFConst.ENUM_REGION_JAPAN {
                    ADFMovieOptions.setRegion(.japan)
                } else if region == ADFConst.ENUM_REGION_FOREIGN {
                    ADFMovieOptions.setRegion(.foreign)
                } else if region == ADFConst.ENUM_REGION_DEVICE {
                    ADFMovieOptions.setRegion(.deviceSetting)
                }
            }
            break
        case ADFConst.METHOD_OUTPUT_DETAILED_LOG:
            ADFLogger.logLevel = .verbose
            break
        default:
            print("[ADF WARNING] \(call.method) method is not implemented")
        }
    }
}
